"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var change_case_1 = __importDefault(require("change-case"));
var JsonApiDeserializer = /** @class */ (function () {
    function JsonApiDeserializer(store) {
        this.store = store;
    }
    JsonApiDeserializer.prototype.deserialize = function (payload) {
        var jsonApi = payload;
        return this._deserialize(jsonApi);
    };
    JsonApiDeserializer.prototype._deserialize = function (payload) {
        var _this = this;
        var primary = payload.data;
        if (payload.included) {
            payload.included.forEach(function (data) { return _this.deserializeRecord(data); });
        }
        if (primary instanceof Array) {
            return primary.map(function (data) { return _this.deserializeRecord(data); });
        }
        return this.deserializeRecord(primary);
    };
    JsonApiDeserializer.prototype.findOrInit = function (record) {
        return this.store.findOrInit(record.type, record.id);
    };
    JsonApiDeserializer.prototype.deserializeRecord = function (record) {
        var instance = this.findOrInit(record);
        if (record.attributes) {
            Object.keys(record.attributes).forEach(function (key) {
                if (record.attributes) {
                    var camelKey = change_case_1.default.camel(key);
                    instance[camelKey] = record.attributes[key];
                }
            });
        }
        if (record.relationships) {
            this.mapRelationships(instance, record.relationships);
        }
        return instance;
    };
    JsonApiDeserializer.prototype.mapRelationships = function (instance, relationships) {
        var _this = this;
        Object.keys(relationships).forEach(function (key) {
            var relationship = relationships[key];
            var camelKey = change_case_1.default.camel(key);
            if (relationship.data instanceof Array) {
                // eslint-disable-next-line no-param-reassign
                instance[camelKey] = relationship.data.map(function (data) {
                    return _this.findOrInit(data);
                });
            }
            else {
                // eslint-disable-next-line no-param-reassign
                instance[camelKey] = _this.findOrInit(relationship.data);
            }
        });
    };
    return JsonApiDeserializer;
}());
exports.JsonApiDeserializer = JsonApiDeserializer;
//# sourceMappingURL=jsonApiDeserializer.js.map