"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var change_case_1 = __importDefault(require("change-case"));
var pluralize_1 = __importDefault(require("pluralize"));
var model_1 = require("./model");
var Store = /** @class */ (function () {
    function Store() {
        this.models = [];
        this.data = {};
    }
    Store.getResourceName = function (model) {
        var name = "";
        if (typeof model === "string") {
            name = model;
        }
        else if (model_1.isModelInstance(model)) {
            name = model.constructor.name;
        }
        else {
            name = model.name;
        }
        return change_case_1.default.camel(pluralize_1.default.plural(name));
    };
    Store.getModelName = function (resource) {
        return change_case_1.default.pascal(pluralize_1.default.singular(resource));
    };
    Store.prototype.define = function (model) {
        var old = this.models.find(function (_model) { return _model === model; });
        if (!old) {
            this.models.push(model);
            var resource = Store.getResourceName(model);
            this.data[resource] = {};
        }
    };
    Store.prototype.getModel = function (resource) {
        var modelName = Store.getModelName(resource);
        var model = this.models.find(function (_model) { return _model.name === modelName; });
        if (model) {
            return model;
        }
        throw new Error("No Model corresponds to " + resource);
    };
    Store.prototype.read = function (payload) {
        return this.deserializer.deserialize(payload);
    };
    Store.prototype.find = function (resource, id) {
        var idString = String(id);
        var resourceName = Store.getResourceName(resource);
        if (!this.data[resourceName] || !this.data[resourceName][idString]) {
            return undefined;
        }
        return this.data[resourceName][id];
    };
    Store.prototype.findAll = function (resource) {
        var _this = this;
        var resourceName = Store.getResourceName(resource);
        if (!this.data[resourceName])
            return [];
        return Object.keys(this.data[resourceName]).map(function (key) { return _this.data[resourceName][key]; });
    };
    Store.prototype.findOrInit = function (resource, id) {
        var old = this.find(resource, id);
        if (old) {
            return old;
        }
        var ModelClass = this.getModel(resource);
        var instance = new ModelClass();
        instance.id = String(id);
        return this.add(instance);
    };
    Store.prototype.destroy = function (instance) {
        var resourceName = Store.getResourceName(instance);
        delete this.data[resourceName][instance.id];
    };
    Store.prototype.reset = function () {
        var _this = this;
        Object.keys(this.data).forEach(function (resource) {
            _this.data[resource] = {};
        });
    };
    Store.prototype.append = function (array, payload) {
        var result = this.read(payload);
        if (result instanceof Array) {
            result.forEach(function (instance) { return array.push(instance); });
        }
        else {
            array.push(result);
        }
        return array;
    };
    Store.prototype.add = function (instance) {
        var resourceName = Store.getResourceName(instance);
        this.data[resourceName][instance.id] = instance;
        return this.data[resourceName][instance.id];
    };
    return Store;
}());
exports.Store = Store;
//# sourceMappingURL=store.js.map