"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var store_1 = require("../../src/store");
var deserializers_1 = require("../../src/deserializers");
var class_1 = require("../class");
var payload_1 = require("../payload");
var store = new store_1.Store();
store.deserializer = new deserializers_1.JsonApiDeserializer(store);
store.define(class_1.Dog);
store.define(class_1.Cat);
store.define(class_1.Owner);
store.define(class_1.Person);
describe("JsonApiDeserializer", function () {
    afterEach(function () {
        store.reset();
    });
    describe("deserialize", function () {
        it("should deserialize single record", function () {
            var result = store.read(payload_1.dogResponse);
            expect(result).toBeInstanceOf(class_1.Dog);
            expect(result.id).toBe("1");
            expect(result.age).toBe("2");
            expect(result.numAge).toBe(2);
        });
        it("should deserialize multiple records", function () {
            var result = store.read(payload_1.dogsResponse);
            expect(result[0]).toBeInstanceOf(class_1.Dog);
            expect(result[0].id).toBe("1");
            expect(result[0].age).toBe("2");
            expect(result[1]).toBeInstanceOf(class_1.Dog);
            expect(result[1].id).toBe("2");
            expect(result[1].age).toBe("3");
        });
        it("should deserialize record with single relationship", function () {
            var result = store.read(payload_1.catResponseWithRelationships);
            expect(result.friend).toBeInstanceOf(class_1.Dog);
            expect(result.friend.id).toBe("1");
            expect(result.friend.age).toBe("2");
        });
        it("should deserialize sync", function () {
            var result = store.read(payload_1.catResponseWithNoIncluded);
            expect(result.friend.age).toBeUndefined();
            store.read(payload_1.dogsResponse);
            expect(result.friend.age).toBe("2");
        });
        it("should deserialize record with multiple relationships", function () {
            var result = store.read(payload_1.ownerResponseWithRelationships);
            expect(result.pets[0]).toBeInstanceOf(class_1.Dog);
            expect(result.pets[0].id).toBe("1");
            expect(result.pets[1]).toBeInstanceOf(class_1.Cat);
            expect(result.pets[1].id).toBe("1");
        });
        it("should deserialize payload in snake case", function () {
            var result = store.read(payload_1.personResponseInSnake);
            expect(result.firstName).toBe("John");
            expect(result.lastName).toBe("Doe");
        });
        it("should deserialize payload in camel case", function () {
            var result = store.read(payload_1.personResponseInCamel);
            expect(result.firstName).toBe("John");
            expect(result.lastName).toBe("Doe");
        });
        it("should return an instance that accept instance method", function () {
            var result = store.read(payload_1.personResponseInCamel);
            expect(result.fullName).toBe("John Doe");
        });
    });
});
//# sourceMappingURL=jsonApiDeserializer.test.js.map