"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var store_1 = require("../src/store");
var class_1 = require("./class");
var payload_1 = require("./payload");
var store = new store_1.Store();
store.define(class_1.Dog);
store.define(class_1.LongNameModel);
describe("Store", function () {
    afterEach(function () {
        store.reset();
    });
    describe("getModel", function () {
        it("should throw error if no model corresponds", function () {
            expect(function () { return store.getModel("horse"); }).toThrow();
        });
        it("should return single Pascal name", function () {
            expect(store.getModel("dog")).toBe(class_1.Dog);
            expect(store.getModel("dogs")).toBe(class_1.Dog);
            expect(store.getModel("long_name_model")).toBe(class_1.LongNameModel);
        });
    });
    describe("static getResourceName", function () {
        it("should accept instance", function () {
            expect(store_1.Store.getResourceName(new class_1.Dog())).toBe("dogs");
            expect(store_1.Store.getResourceName(new class_1.LongNameModel())).toBe("longNameModels");
        });
        it("should accept class", function () {
            expect(store_1.Store.getResourceName(class_1.Dog)).toBe("dogs");
            expect(store_1.Store.getResourceName(class_1.LongNameModel)).toBe("longNameModels");
        });
        it("should accept string", function () {
            expect(store_1.Store.getResourceName("dog")).toBe("dogs");
            expect(store_1.Store.getResourceName("dogs")).toBe("dogs");
            expect(store_1.Store.getResourceName("long_name_model")).toBe("longNameModels");
            expect(store_1.Store.getResourceName("long_name_models")).toBe("longNameModels");
        });
    });
    describe("find", function () {
        it("should return an instance if it exists in store", function () {
            var dog = store.findOrInit("dog", 1);
            expect(store.find("dog", "1")).toBe(dog);
        });
        it("should return undefined if it does not exists in store", function () {
            expect(store.find("dog", "1")).toBeUndefined();
        });
    });
    describe("findAll", function () {
        it("should return an Array", function () {
            store.findOrInit("dog", 1);
            store.findOrInit("dog", 2);
            expect(store.findAll("dog")).toBeInstanceOf(Array);
            expect(store.findAll("dog").length).toBe(2);
        });
    });
    describe("destroy", function () {
        it("should delete instance frmo store", function () {
            var dog = store.findOrInit("dog", 1);
            expect(store.find("dog", "1")).toBe(dog);
            store.destroy(dog);
            expect(store.find("dog", "1")).toBeUndefined();
        });
    });
    describe("append", function () {
        it("should accept append single record", function () {
            // eslint-disable-next-line @typescript-eslint/no-unused-vars
            store.read = jest.fn().mockImplementationOnce(function (payload) { return new class_1.Dog(); });
            var array = [new class_1.Dog(), new class_1.Dog()];
            store.append(array, payload_1.dogResponse);
            expect(array.length).toBe(3);
        });
        it("should accept append multiple records", function () {
            store.read = jest
                .fn()
                // eslint-disable-next-line @typescript-eslint/no-unused-vars
                .mockImplementationOnce(function (payload) { return [new class_1.Dog(), new class_1.Dog()]; });
            var array = [new class_1.Dog(), new class_1.Dog()];
            store.append(array, payload_1.dogsResponse);
            expect(array.length).toBe(4);
        });
    });
});
//# sourceMappingURL=store.test.js.map